package controller

import (
	"github.com/gofiber/fiber/v2"
	"github.com/nicksnyder/go-i18n/v2/i18n"
	"golang.org/x/text/language"
	"ulmer-furs.de/pretix-proxy/v2/app/service"
	"ulmer-furs.de/pretix-proxy/v2/config"
)

// @Description Get the attendies of an event by the name
func GetAttendiesByEventPublic(c *fiber.Ctx) error {
	name := c.Params("name")
	event, err := service.Get_db_event_by_event(name)
	if err != nil {
		return c.Status(fiber.ErrNotFound.Code).SendString("event not found")
	}
	attendies, err := service.GetAttendiesByEventPrivacy(event, false)
	if err != nil {
		return c.Status(fiber.ErrNotFound.Code).SendString("attendies not found")
	}
	c.JSON(attendies)
	return c.SendStatus(fiber.StatusOK)
}

func GetAttendiesByEventPublicTable(c *fiber.Ctx) error {
	siteLang := c.Query("lang")
	var localizer *i18n.Localizer
	if siteLang == "de-DE" {
		localizer = i18n.NewLocalizer(config.LocaleBundle, language.German.String())
	} else {
		localizer = i18n.NewLocalizer(config.LocaleBundle)
	}
	name := c.Params("name")
	event, err := service.Get_db_event_by_event(name)
	if err != nil {
		return c.Status(fiber.ErrNotFound.Code).SendString("event not found")
	}
	attendies, err := service.GetAttendiesByEventPrivacy(event, false)
	if err != nil {
		return c.Status(fiber.ErrNotFound.Code).SendString("attendies not found")
	}
	localizations := map[string]string{
		"Attendie": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Attendie",
			PluralCount: 2,
		}),
		"HelloWorld": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID: "HelloWorld",
		}),
		"Role": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Role",
			PluralCount: 1,
		}),
		"Name": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Name",
			PluralCount: 1,
		}),
		"Guest": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Guest",
			PluralCount: 1,
		}),
		"Spotter": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Spotter",
			PluralCount: 1,
		}),
		"Suiter": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Suiter",
			PluralCount: 1,
		}),
		"Photographer": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Photographer",
			PluralCount: 1,
		}),
		"SpecialAnimal": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "SpecialAnimal",
			PluralCount: 1,
		}),
		"Registered": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID: "Registered",
		}),
		"SuiterWaitinglist": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID: "SuiterWaitinglist",
		}),
		"WaitinglistDesc": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID: "WaitinglistDesc",
		}),
		"Restaurant": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "Restaurant",
			PluralCount: 1,
		}),
		"Yes": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID: "Yes",
		}),
		"No": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID: "No",
		}),
		"AfterParty": localizer.MustLocalize(&i18n.LocalizeConfig{
			MessageID:   "AfterParty",
			PluralCount: 1,
		}),
	}
	return c.Render("app/views/index", fiber.Map{
		"EventName": *(event).Name,
		"Attendies": attendies,
		"Locals":    localizations,
		"EventType": *(event).EventType,
	})
}
