package controller

import (
	"strconv"

	"github.com/gofiber/fiber/v2"
	"github.com/jinzhu/copier"
	"ulmer-furs.de/pretix-proxy/v2/app/service"
	"ulmer-furs.de/pretix-proxy/v2/app/util"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

func ReturnEventsTableView(c *fiber.Ctx) error {
	events, err := service.Get_all_db_event()
	if err != nil {
		return c.Status(500).Render("app/index/index", fiber.Map{
			"Error": err.Error(),
		})
	}
	return c.Render("app/views/index", fiber.Map{
		"Title":  "Ulmer Furs Events",
		"Events": events,
		"Count":  len(events),
	})
}

func ReturnAllEvents(c *fiber.Ctx) error {
	events, err := service.Get_all_db_event()
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	c.JSON(events)
	return c.SendStatus(200)
}

func ReturnAllEventsPublic(c *fiber.Ctx) error {
	events, err := service.Get_all_db_event()
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	publicEvets := new([]entities.Db_Event_Public)
	err = copier.Copy(publicEvets, events)
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	c.JSON(publicEvets)
	return c.SendStatus(fiber.StatusOK)
}

func ReturnEventById(c *fiber.Ctx) error {
	id := c.Params("id")
	id_int, err := strconv.Atoi(id)
	if err != nil {
		return c.Status(400).SendString("Bad Request")
	}
	event, err := service.Get_db_event_by_id(id_int)
	if err != nil {
		return c.Status(404).SendString(err.Error())
	}
	c.JSON(event)
	return c.SendStatus(200)
}

func DeleteEventById(c *fiber.Ctx) error {
	id := c.Params("id")
	id_int, err := strconv.Atoi(id)
	if err != nil {
		return c.Status(400).SendString("Bad Request")
	}
	if _, err := service.Get_db_event_by_id(id_int); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrNotFound.Code,
			Message: "Event not found",
		}
	}
	if err := service.Delete_db_event_by_id(id_int); err != nil {
		return c.Status(404).SendString(err.Error())
	}
	return c.SendStatus(200)
}

func CreateEvent(c *fiber.Ctx) error {
	event := new(entities.Db_Event)
	if err := c.BodyParser(event); err != nil {
		return c.Status(fiber.ErrBadRequest.Code).SendString("Bad Request")
	}

	if err, errMsg := util.Validate(event); err {
		return &fiber.Error{
			Code:    fiber.ErrBadRequest.Code,
			Message: errMsg,
		}
	}
	if err := service.Create_new_db_event(*event); err != nil {
		return c.Status(fiber.ErrInternalServerError.Code).SendString(err.Error())
	}
	return c.SendStatus(fiber.StatusOK)
}

func UpdateEventById(c *fiber.Ctx) error {
	event := new(entities.Db_Event)
	id := c.Params("id")
	id_int, parseErr := strconv.Atoi(id)
	if err := c.BodyParser(event); err != nil || parseErr != nil {
		return c.Status(400).SendString("Bad Request")
	}
	if _, err := service.Get_db_event_by_id(id_int); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrNotFound.Code,
			Message: "Event not found",
		}
	}
	event.ID = uint(id_int)
	if err := service.Update_db_event(*event); err != nil {
		return c.Status(500).SendString(err.Error())
	}
	return c.SendStatus(200)
}
