package controller

import (
	"strconv"

	"github.com/gofiber/fiber/v2"
	"ulmer-furs.de/pretix-proxy/v2/app/service"
	"ulmer-furs.de/pretix-proxy/v2/app/util"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

func ReturnRoleById(c *fiber.Ctx) error {
	id := c.Params("id")
	id_int, err := strconv.Atoi(id)
	if err != nil {
		return c.Status(fiber.StatusBadRequest).SendString("Bad Request")
	}
	role, err := service.GetRoleById(id_int)
	if err != nil {
		return c.Status(fiber.StatusNotFound).SendString(err.Error())
	}
	c.JSON(role)
	return c.SendStatus(fiber.StatusOK)
}

func CreateRole(c *fiber.Ctx) error {
	role := new(entities.Role)
	if err := c.BodyParser(role); err != nil {
		return c.Status(fiber.StatusBadRequest).SendString("Bad Request")
	}
	if err, errMsg := util.Validate(role); err {
		return &fiber.Error{
			Code:    fiber.ErrBadRequest.Code,
			Message: errMsg,
		}
	}
	if err := service.CreateNewRole(*role); err != nil {
		return c.Status(fiber.ErrInternalServerError.Code).SendString(err.Error())
	}
	return c.SendStatus(fiber.StatusOK)
}

func UpdateRoleById(c *fiber.Ctx) error {
	role := new(entities.Role)
	id := c.Params("id")
	id_int, parseErr := strconv.Atoi(id)
	if err := c.BodyParser(role); err != nil || parseErr != nil {
		return c.Status(400).SendString("Bad Request")
	}
	if _, err := service.GetRoleById(id_int); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrNotFound.Code,
			Message: "Event not found",
		}
	}
	role.ID = uint(id_int)
	if err := service.UpdateRole(*role); err != nil {
		return c.Status(500).SendString(err.Error())
	}
	return c.SendStatus(200)
}

func DeleteRoleById(c *fiber.Ctx) error {
	id := c.Params("id")
	id_int, err := strconv.Atoi(id)
	if err != nil {
		return c.Status(400).SendString("Bad Request")
	}
	if _, err := service.GetRoleById(id_int); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrNotFound.Code,
			Message: "Role not found",
		}
	}
	if err := service.DeleteRole(id_int); err != nil {
		return c.Status(404).SendString(err.Error())
	}
	return c.SendStatus(200)
}

func ReturnAllRoles(c *fiber.Ctx) error {
	roles, err := service.GetAllRoles()
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	c.JSON(roles)
	return c.SendStatus(200)
}
