package controller

import (
	"github.com/gofiber/fiber/v2"
	"golang.org/x/crypto/bcrypt"
	"ulmer-furs.de/pretix-proxy/v2/app/service"
	"ulmer-furs.de/pretix-proxy/v2/app/util"
	"ulmer-furs.de/pretix-proxy/v2/entities"
	"ulmer-furs.de/pretix-proxy/v2/entities/responses"
)

func CreateUser(c *fiber.Ctx) error {
	user := new(entities.User)
	if err := c.BodyParser(user); err != nil {
		return c.Status(fiber.ErrBadRequest.Code).SendString("Bad Request")
	}
	if err, errMsg := util.Validate(user); err {
		return &fiber.Error{
			Code:    fiber.ErrBadRequest.Code,
			Message: errMsg,
		}
	}
	if hashedPassword, err := bcrypt.GenerateFromPassword([]byte(user.Password), bcrypt.DefaultCost); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrInternalServerError.Code,
			Message: "Internal Server Error",
		}
	} else {
		user.HashedPassword = hashedPassword
	}
	if err := service.Create_User(user); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrInternalServerError.Code,
			Message: "Internal Server Error",
		}
	}
	token, err := util.CreateToken(user)
	if err != nil {
		return &fiber.Error{
			Code:    fiber.ErrInternalServerError.Code,
			Message: "Internal Server Error",
		}
	}
	c.JSON(responses.UserResponse{
		Token: token,
	})
	return c.SendStatus(fiber.StatusOK)
}

func LoginUser(c *fiber.Ctx) error {
	credentials := new(entities.User)
	if err := c.BodyParser(credentials); err != nil {
		return &fiber.Error{
			Code:    fiber.ErrUnauthorized.Code,
			Message: "Unauthorized",
		}
	}
	user, err := service.GetUserByEmail(credentials.Email)
	if err != nil {
		return &fiber.Error{
			Code:    fiber.ErrUnauthorized.Code,
			Message: "Unauthorized",
		}
	}
	err = bcrypt.CompareHashAndPassword(user.HashedPassword, []byte(credentials.Password))
	if err != nil {
		return &fiber.Error{
			Code:    fiber.ErrUnauthorized.Code,
			Message: "Unauthorized",
		}
	}
	token, err := util.CreateToken(&user)
	if err != nil {
		return &fiber.Error{
			Code:    fiber.ErrInternalServerError.Code,
			Message: "Internal Server Error",
		}
	}
	c.JSON(responses.UserResponse{
		Token: token,
	})
	return c.SendStatus(fiber.StatusOK)
}
