package controller

import (
	"fmt"

	"github.com/gofiber/fiber/v2"
	"ulmer-furs.de/pretix-proxy/v2/app/service"
	"ulmer-furs.de/pretix-proxy/v2/app/util"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

func PostPretixRoleQuestion(c *fiber.Ctx) error {
	data := new(entities.Pretix_Webhook)
	if err := c.BodyParser(data); err != nil {
		return c.Status(fiber.ErrBadRequest.Code).SendString(err.Error())
	}
	pretixOrders, err := getAllPretixOrders(&data.Organizer, &data.Event)
	if err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	event, err := service.Get_db_event_by_event(data.Event)
	if err != nil {
		return c.Status(fiber.StatusNotFound).SendString("Event not found")
	}
	attendies, err := util.GetAttendiesFromPretixJsonWithRoleQuestion(pretixOrders, &event)
	if err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	if err := service.DeleteAttendiesByEvent(event); err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	for _, attendie := range attendies {
		if err := service.CreateNewAttendie(attendie); err != nil {
			fmt.Print(err)
			return c.SendStatus(fiber.StatusInternalServerError)
		}
	}
	return c.SendStatus(fiber.StatusOK)
}

func PostPretixRoleProduct(c *fiber.Ctx) error {
	data := new(entities.Pretix_Webhook)
	if err := c.BodyParser(data); err != nil {
		return c.Status(fiber.ErrBadRequest.Code).SendString(err.Error())
	}
	pretixOrders, err := getAllPretixOrders(&data.Organizer, &data.Event)
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	event, err := service.Get_db_event_by_event(data.Event)
	if err != nil {
		return c.Status(fiber.StatusNotFound).SendString("Event not found")
	}
	attendies, err := util.GetAttendiesFromPretixJsonWithRoleProduct(pretixOrders, &event)
	if err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	if err := service.DeleteAttendiesByEvent(event); err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	for _, attendie := range attendies {
		if err := service.CreateNewAttendie(attendie); err != nil {
			fmt.Print(err)
			return c.SendStatus(fiber.StatusInternalServerError)
		}
	}
	return c.SendStatus(fiber.StatusOK)
}

func PostPretixRegularsTable(c *fiber.Ctx) error {
	data := new(entities.Pretix_Webhook)
	if err := c.BodyParser(data); err != nil {
		return c.Status(fiber.ErrBadRequest.Code).SendString(err.Error())
	}
	pretixOrders, err := getAllPretixOrders(&data.Organizer, &data.Event)
	if err != nil {
		return c.Status(500).SendString("Internal Server Error")
	}
	event, err := service.Get_db_event_by_event(data.Event)
	if err != nil {
		return c.Status(fiber.StatusNotFound).SendString("Event not found")
	}
	attendies, err := util.GetAttendiesFromPretixJsonWithSeperateSubProducts(pretixOrders, &event)
	if err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	if err := service.DeleteAttendiesByEvent(event); err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	for _, attendie := range attendies {
		if err := service.CreateNewAttendie(attendie); err != nil {
			fmt.Print(err)
			return c.SendStatus(fiber.StatusInternalServerError)
		}
	}
	return c.SendStatus(fiber.StatusOK)
}

func PostPretixSpecialEventWithRoles(c *fiber.Ctx) error {
	data := new(entities.Pretix_Webhook)
	if err := c.BodyParser(data); err != nil {
		return c.Status(fiber.ErrBadRequest.Code).SendString(err.Error())
	}
	pretixOrders, err := getAllPretixOrders(&data.Organizer, &data.Event)
	if err != nil {
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	event, err := service.Get_db_event_by_event(data.Event)
	if err != nil {
		return c.Status(fiber.StatusNotFound).SendString("Event not found")
	}
	attendies, err := util.GetAttendiesFromPretixJsonWithRoleQuestionNoSubproducts(
		pretixOrders,
		&event,
	)
	if err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	if err := service.DeleteAttendiesByEvent(event); err != nil {
		fmt.Println(err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	for _, attendie := range attendies {
		if err := service.CreateNewAttendie(attendie); err != nil {
			fmt.Print(err)
			return c.SendStatus(fiber.StatusInternalServerError)
		}
	}
	return c.SendStatus(fiber.StatusOK)
}

func getAllPretixOrders(organizer, event *string) (*entities.Pretix_Event, error) {
	pretixOrders, err := util.GetPretixOrders(organizer, event)
	for link := pretixOrders.Next; link != nil; {
		next_page, err := util.GetPretixOrdersByLink(link)
		if err != nil {
			return nil, err
		}
		pretixOrders.Results = append(pretixOrders.Results, next_page.Results...)
		link = next_page.Next
	}
	return pretixOrders, err
}
