package service

import (
	"errors"

	"gorm.io/gorm"
	"ulmer-furs.de/pretix-proxy/v2/config"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

func Get_db_event_by_id(id int) (entities.Db_Event, error) {
	var db_event entities.Db_Event
	result := config.Database.Find(&db_event, id)
	if result.RowsAffected == 0 {
		return db_event, errors.New("event not found")
	}
	return db_event, nil
}

func Get_db_event_by_event(name string) (entities.Db_Event, error) {
	var db_event entities.Db_Event
	result := config.Database.First(&db_event, "event = ?", name)
	if result.RowsAffected == 0 {
		return db_event, errors.New("event not found")
	}
	return db_event, nil
}

func Get_all_db_event() ([]entities.Db_Event, error) {
	var db_events []entities.Db_Event
	result := config.Database.Find(&db_events)
	if errors.Is(result.Error, gorm.ErrRecordNotFound) {
		return db_events, errors.New("events not found")
	}
	return db_events, nil

}

func Create_new_db_event(event entities.Db_Event) error {
	result := config.Database.Create(&event)
	if result.Error != nil {
		return result.Error
	}
	return nil
}

func Update_db_event(event entities.Db_Event) error {
	result := config.Database.Save(event)
	if result.Error != nil {
		return result.Error
	}
	return nil
}

func Delete_db_event_by_id(id int) error {
	result := config.Database.Delete(&entities.Db_Event{}, id)
	if result.Error != nil {
		return result.Error
	}
	return nil
}
