package service

import (
	"errors"

	"gorm.io/gorm"
	"ulmer-furs.de/pretix-proxy/v2/config"
	"ulmer-furs.de/pretix-proxy/v2/entities"
)

func GetRoleById(id int) (*entities.Role, error) {
	var role *entities.Role
	result := config.Database.Find(role, id)
	if result.RowsAffected == 0 {
		return role, errors.New("role not found")
	}
	return role, nil
}

func GetRoleByName(name string) (*entities.Role, error) {
	var role *entities.Role
	result := config.Database.First(&role, "name = ?", name)
	if result.RowsAffected == 0 {
		return role, errors.New("role not found")
	}
	return role, nil
}

func GetAllRoles() ([]entities.Role, error) {
	var roles []entities.Role
	result := config.Database.Find(&roles)
	if errors.Is(result.Error, gorm.ErrRecordNotFound) {
		return roles, errors.New("roles not found")
	}
	return roles, nil
}

func CreateNewRole(role entities.Role) error {
	result := config.Database.Create(&role)
	if result.Error != nil {
		return result.Error
	}
	return nil
}

func UpdateRole(role entities.Role) error {
	result := config.Database.Save(role)
	if result.Error != nil {
		return result.Error
	}
	return nil
}

func DeleteRole(id int) error {
	result := config.Database.Delete(&entities.Role{}, id)
	if result.Error != nil {
		return result.Error
	}
	return nil
}
