package config

import (
	"fmt"
	"log"

	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
	"ulmer-furs.de/pretix-proxy/v2/entities"
	"ulmer-furs.de/pretix-proxy/v2/seeder"
)

var Database *gorm.DB

func Connect() error {
	var err error
	Database, err = gorm.Open(sqlite.Open(Env.DatabasePath), &gorm.Config{})

	if err != nil {
		panic(err)
	}

	Database.AutoMigrate(
		&entities.Db_Event{},
		&entities.Db_Attendies{},
		&entities.User{},
		&entities.Role{},
	)

	if isEmpty(&entities.Role{}) {
		for _, seed := range seeder.Roles() {
			runSeeder(seed)
		}
	}

	return nil
}

func isEmpty(entity interface{}) bool {
	var count int64
	Database.Find(entity).Count(&count)
	return count == 0
}

func runSeeder(seed entities.Seed) {
	fmt.Printf("Run Migration: %s\n", seed.Name)
	if err := seed.Run(Database); err != nil {
		log.Fatalf("Running seed '%s', failed with error: %s", seed.Name, err)
	}
}
