package config

import (
	"embed"
	"encoding/json"

	"github.com/nicksnyder/go-i18n/v2/i18n"
	"golang.org/x/text/language"
)

var LocaleBundle *i18n.Bundle

func SetupLocalization(locaizationFS *embed.FS) {
	LocaleBundle = i18n.NewBundle(language.English)
	for _, message := range defaultMessages {
		LocaleBundle.AddMessages(language.English, &message)
	}
	LocaleBundle.RegisterUnmarshalFunc("json", json.Unmarshal)
	LocaleBundle.LoadMessageFileFS(locaizationFS, "localization/active.de.json")
}

var defaultMessages = []i18n.Message{
	{
		ID:    "HelloWorld",
		Other: "Hello newer World",
	},
	{
		ID:    "Attendie",
		One:   "Attendie",
		Other: "Attendies",
	},
	{
		ID:    "Role",
		One:   "Role",
		Other: "Roles",
	},
	{
		ID:    "Name",
		One:   "Name",
		Other: "Names",
	},
	{
		ID:    "Registered",
		Other: "Registered",
	},
	{
		ID:    "SuiterWaitinglist",
		Other: "Suiter Watinglist",
	},
	{
		ID:    "WaitinglistDesc",
		Other: "We set a ratio of Suiters per Spotter for each event in order to keep the count of suiters manageble for them. If you are listed here we don't have enough spotters yet.",
	},
	{
		ID:    "Suiter",
		One:   "Suiter",
		Other: "Suiters",
	},
	{
		ID:    "Guest",
		One:   "Guest",
		Other: "Guets",
	},
	{
		ID:    "Spotter",
		One:   "Spotter",
		Other: "Spotters",
	},
	{
		ID:    "Photographer",
		One:   "Photographer",
		Other: "Photographers",
	},
	{
		ID:    "SpecialAnimal",
		One:   "#SpecialAnimal",
		Other: "#SpecialAnimals",
	},
	{
		ID:    "Restaurant",
		One:   "Restaurant",
		Other: "Restaurantes",
	},
	{
		ID:    "Yes",
		Other: "Yes",
	},
	{
		ID:    "No",
		Other: "No",
	},
	{
		ID:    "AfterParty",
		One:   "AfterParty",
		Other: "AfterParties",
	},
}
