package config

import (
	"crypto/sha256"
	"crypto/subtle"

	jwtware "github.com/gofiber/contrib/jwt"
	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/fiber/v2/middleware/keyauth"
)

var AuthMiddleware fiber.Handler
var JwtMiddleware fiber.Handler

func SetupMiddlewares() {
	AuthMiddleware = keyauth.New(keyauth.Config{
		Validator: func(c *fiber.Ctx, key string) (bool, error) {
			hashedAPIKey := sha256.Sum256([]byte(Env.ApiKey))
			hashedKey := sha256.Sum256([]byte(key))
			if subtle.ConstantTimeCompare(hashedAPIKey[:], hashedKey[:]) == 1 {
				return true, nil
			}
			return false, keyauth.ErrMissingOrMalformedAPIKey
		},
	})
	JwtMiddleware = jwtware.New(jwtware.Config{
		SigningKey: jwtware.SigningKey{Key: []byte(Env.Secret)},
	})
}
